@@ -4,7 +4,6 @@ from typing import Optional
 import msgspec
 
 from pyrrhic.crypto.keys import decrypt_mac
-from pyrrhic.repo.pack import Pack
 from pyrrhic.repo.repository import Repository
 
 
@@ -32,9 +31,8 @@ class Tree(msgspec.Struct):
 def get_node_blob(repo: Repository, blob_id: str) -> bytes:
     index = repo.get_index()
     packref = index.get_packref(blob_id)
-    pack = Pack(repo.repository, repo.masterkey, packref.id)
     blob = packref.blob
-    with open(repo.repository / "data" / pack.pack_id[:2] / pack.pack_id, "rb") as f:
+    with open(repo.repository / "data" / packref.id[:2] / packref.id, "rb") as f:
         f.seek(blob.offset)
         buffer = f.read(blob.length)
         plaintext = decrypt_mac(repo.masterkey, buffer)
